@@ -707,7 +707,7 @@ class CronLineTimeAction(object):
 
     # User checks.
     if self.user in USER_WHITELIST:
-      return
+      pass
     elif len(self.user) > 31:
       log.LineError(log.MSG_INVALID_USER,
                     'Username too long "%s"' % self.user)
@@ -1062,6 +1062,7 @@ def check_crontab(crontab_file, log, whitelisted_users=None):
 
   # Check if the file even exists.
   if not os.path.exists(crontab_file):
+    log.Warn('File "%s" does not exist.' % crontab_file)
     return log.Summary()
 
   # Add the any specified users to the whitelist
@@ -1083,6 +1084,8 @@ def check_crontab(crontab_file, log, whitelisted_users=None):
   cron_line_factory = CronLineFactory()
   with open(crontab_file, 'r') as crontab_f:
     for line in crontab_f:
+      missing_newline = line[-1] != "\n"
+
       line = line.strip()
       line_no += 1
 
@@ -1091,5 +1094,9 @@ def check_crontab(crontab_file, log, whitelisted_users=None):
 
       log.Emit(line_no, line)
 
+      # are we missing a trailing newline?
+      if missing_newline:
+        log.Error('Cron will not process this file - missing trailing newline')
+
   # Summarize the log messages if there were any.
   return log.Summary()
